
/* - ***** BEGIN LICENSE BLOCK *****
   - Version: MPL 1.1/GPL 2.0/LGPL 2.1
   -
   - The contents of this file are subject to the Mozilla Public License Version
   - 1.1 (the "License"); you may not use this file except in compliance with
   - the License. You may obtain a copy of the License at
   - http://www.mozilla.org/MPL/
   -
   - Software distributed under the License is distributed on an "AS IS" basis,
   - WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
   - for the specific language governing rights and limitations under the
   - License.
   -
   - The Original Code is install.js.
   -
   - The Initial Developer of the Original Code is the Mozilla Foundation.
   - Portions created by the Initial Developer are Copyright (C) 2006
   - the Initial Developer. All Rights Reserved.
   -
   - Contributor(s):
   -   Philip Chee (philip.chee@gmail.com)
   -   deathburger (http://users.linkfilter.net/~deathburger/)
   -   This code is inspired by Chris Pederick (useragentswitcher) install.js
   -
   - Alternatively, the contents of this file may be used under the terms of
   - either the GNU General Public License Version 2 or later (the "GPL"), or
   - the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
   - in which case the provisions of the GPL or the LGPL are applicable instead
   - of those above. If you wish to allow use of your version of this file only
   - under the terms of either the GPL or the LGPL, and not to allow others to
   - use your version of this file under the terms of the MPL, indicate your
   - decision by deleting the provisions above and replace them with the notice
   - and other provisions required by the LGPL or the GPL. If you do not delete
   - the provisions above, a recipient may use your version of this file under
   - the terms of any one of the MPL, the GPL or the LGPL.
   -
   - ***** END LICENSE BLOCK *****
*/

// Editable Items Begin
var displayName         = "Leak Monitor";
var version             = "0.3.4";
var name                = "leakmonitor";
var jarName             = "leakmon.jar";

var packageDir           = "/"
var localeDir           = "/"

var locales             = new Array( "en-US", "ru", "de", "fr" );

// Platform specific components
var components          = [ ["components/leakmonitor.xpt", "leakmonitor.xpt"] ];
var platformStr = new String(Install.platform);
if (!platformStr.search(/^Win/)) {
    components.push( ["platform/WINNT_x86-msvc/components/leakmon.dll", "leakmon.dll"] );
}
else if (/linux.*i686/i.test(platformStr)) {
    components.push( ["platform/Linux_x86-gcc3/components/libleakmon.so", "libleakmon.so"] );
}
else if (/linux.*x86_64/i.test(platformStr)) {
    components.push( ["platform/Linux_x86_64-gcc3/components/libleakmon.so", "libleakmon.so"] );
}
else if (/.*Darwin/i.test(platformStr)) {
    components.push( ["platform/Darwin_ppc-gcc3/components/libleakmon.dylib", "libleakmon-ppc.dylib"] );
    components.push( ["platform/Darwin_x86-gcc3/components/libleakmon.dylib", "libleakmon-x86.dylib"] );
}
else {
    alert("Your operating system (" + Install.platform + ") does not appear to be supported");
    cancelInstall(error);
}
// Editable Items End

var jarFolder           = "content" + packageDir
var error               = null;

var folder              = getFolder("Chrome");
var compFolder          = getFolder("Components");

var existsInApplication = File.exists(getFolder(getFolder("chrome"), jarName));
var existsInProfile     = File.exists(getFolder(folder, jarName));

var contentFlag         = CONTENT | DELAYED_CHROME;
var localeFlag          = LOCALE | DELAYED_CHROME;
var skinFlag            = SKIN | DELAYED_CHROME;

initInstall(displayName, name, version);
setPackageFolder(folder);
error = addFile(name, version, "chrome/" + jarName, folder, null);

// If adding the JAR file succeeded
if(error == SUCCESS)
{
    folder = getFolder(folder, jarName);

    registerChrome(contentFlag, folder, jarFolder);

    for (var i = 0; i < locales.length; i++) {
        registerChrome(localeFlag, folder, "locale/" + locales[i] + localeDir);
    }

    for (var i = 0; i < components.length; i++) {
// Platform specific components installation
        addFile(name, version, components[i][0],
            compFolder, components[i][1], true);
    }

    error = performInstall();

    // If the install failed
    if(error != SUCCESS && error != REBOOT_NEEDED)
    {
        displayError(error);
    	cancelInstall(error);
    }
    else
    {
        alert("The installation of the " + displayName + " extension succeeded.");
    }
}
else
{
    displayError(error);
	cancelInstall(error);
}

// Displays the error message to the user
function displayError(error)
{
    // If the error code was -215
    if(error == READ_ONLY)
    {
        alert("The installation of " + displayName +
            " failed.\nOne of the files being overwritten is read-only.");
    }
    // If the error code was -235
    else if(error == INSUFFICIENT_DISK_SPACE)
    {
        alert("The installation of " + displayName +
            " failed.\nThere is insufficient disk space.");
    }
    // If the error code was -239
    else if(error == CHROME_REGISTRY_ERROR)
    {
        alert("The installation of " + displayName +
            " failed.\nChrome registration failed.");
    }
    else
    {
        alert("The installation of " + displayName +
            " failed.\nThe error code is: " + error);
    }
}